==> haskell-html-entity-map-0.1.0.0-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-EzcT9uIbTY9KyiFIbBqbgl
key:                  html-entity-map-0.1.0.0-EzcT9uIbTY9KyiFIbBqbgl
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  6b2cf7108ba184ed74befb742af2d1d2
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.2.8/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-EzcT9uIbTY9KyiFIbBqbgl
depends:
    base-4.16.4.0 text-1.2.5.0
    unordered-containers-0.2.20-B4pxT3iF0jR7WvKg6foz6h

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-entity-map-0.1.0.0-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-3RdYOP81dQtET7Vd7XeubM
key:                  html-entity-map-0.1.0.0-3RdYOP81dQtET7Vd7XeubM
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  bbfaab5eee8c90e4984fe7c62b394361
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.2.8/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-3RdYOP81dQtET7Vd7XeubM
depends:
    base-4.16.4.0 text-1.2.5.0
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
